@@ -17,44 +17,12 @@
 #' @param ... Other parameters pass to \link{textbox},
 #'
 #' @seealso \code{\link{add_side_box}} \code{\link{add_split}} \code{\link{textbox}} 
+#' \code{\link{add_label_box}}
 #' @return A \code{consort} object.
 #'
 #' @export
 #'
-#' @examples
-#' txt1 <- "Population (n=300)"
-#' txt1_side <- "Excluded (n=15): \n
-#'               \u2022 MRI not collected (n=3)\n
-#'               \u2022 Tissues not collected (n=4)\n
-#'               \u2022 Other (n=8)"
-#'
-#' g <- add_box(txt = txt1)
-#'
-#' g <- add_side_box(g, txt = txt1_side)
-#'
-#' g <- add_box(g, txt = "Randomized (n=200)")
-#'
-#' g <- add_split(g, txt = c("Arm A (n=100)", "Arm B (n=100"))
-#' g <- add_side_box(g,
-#'   txt = c(
-#'     "Excluded (n=15):\n
-#'                   \u2022 MRI not collected (n=3)\n
-#'                    \u2022 Tissues not collected (n=4)\n
-#'                    \u2022 Other (n=8)",
-#'     "Excluded (n=15):\n
-#'                     \u2022 MRI not collected (n=3)\n
-#'                     \u2022 Tissues not collected (n=4)"
-#'   )
-#' )
-#'
-#' g <- add_box(g,
-#'   txt = c(
-#'     "Final analysis (n=100)",
-#'     "Final analysis (n=100"
-#'   )
-#' )
-#' 
-#' 
+#' @example inst/examples/add-box-example.R
 add_box <- function(prev_box = NULL,
                     txt,
                     just = c("center", "left", "right"),
@@ -91,7 +59,6 @@ add_box <- function(prev_box = NULL,
       prev_nodes <- rep(prev_nodes, length(txt))
 
     # Create node
-
     nodes <- lapply(seq_along(txt), function(i){
       box <- do.call(textbox, c(list(text = txt[i], just = just, 
                                      box_fn = rectGrob, 
@@ -101,6 +68,9 @@ add_box <- function(prev_box = NULL,
       }else{
         prev_nd <- prev_nodes[i]
       }
+
+      if(length(txt) == length(prev_nodes) && is_empty(prev_box[[prev_nd]]$text))
+        prev_nd <- prev_box[[prev_nd]]$prev_node
         
 
       list(
